@@ -4,12 +4,11 @@
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
-#ifndef LIBKGAPI2_DRIVEDRIVES_H
-#define LIBKGAPI2_DRIVEDRIVES_H
+#pragma once
 
-#include "types.h"
-#include "object.h"
 #include "kgapidrive_export.h"
+#include "object.h"
+#include "types.h"
 
 #include <QString>
 
@@ -30,11 +29,9 @@ namespace Drive
  * @since 5.11.41
  * @author David Barchiesi <david@barchie.si>
  */
-class KGAPIDRIVE_EXPORT Drives: public KGAPI2::Object
+class KGAPIDRIVE_EXPORT Drives : public KGAPI2::Object
 {
-
-  public:
-
+public:
     /**
      * @brief Drives::Restrictions holds the structure used for
      * a set of restrictions that apply to this shared drive
@@ -42,8 +39,7 @@ class KGAPIDRIVE_EXPORT Drives: public KGAPI2::Object
      */
     class Restrictions
     {
-
-      public:
+    public:
         struct Fields {
             static const QString AdminManagedRestrictions;
             static const QString CopyRequiresWriterPermission;
@@ -55,7 +51,10 @@ class KGAPIDRIVE_EXPORT Drives: public KGAPI2::Object
         Restrictions(const Restrictions &other);
         ~Restrictions();
         bool operator==(const Restrictions &other) const;
-        bool operator!=(const Restrictions &other) const { return !operator==(other); }
+        bool operator!=(const Restrictions &other) const
+        {
+            return !operator==(other);
+        }
 
         /**
          * @brief Returns whether administrative privileges on this shared
@@ -121,14 +120,14 @@ class KGAPIDRIVE_EXPORT Drives: public KGAPI2::Object
          */
         void setDriveMembersOnly(bool driveMembersOnly) const;
 
-      private:
+    private:
         class Private;
         QScopedPointer<Private> const d;
         friend class Private;
         friend class Drives;
     };
 
-    typedef QSharedPointer<Restrictions> RestrictionsPtr;
+    using RestrictionsPtr = QSharedPointer<Restrictions>;
 
     /**
      * @brief Drives::Capabilities holds the structure used for
@@ -136,8 +135,7 @@ class KGAPIDRIVE_EXPORT Drives: public KGAPI2::Object
      */
     class Capabilities
     {
-
-      public:
+    public:
         struct Fields {
             static const QString CanAddChildren;
             static const QString CanChangeCopyRequiresWriterPermissionRestriction;
@@ -163,7 +161,10 @@ class KGAPIDRIVE_EXPORT Drives: public KGAPI2::Object
         Capabilities(const Capabilities &other);
         ~Capabilities();
         bool operator==(const Capabilities &other) const;
-        bool operator!=(const Capabilities &other) const { return !operator==(other); }
+        bool operator!=(const Capabilities &other) const
+        {
+            return !operator==(other);
+        }
 
         /**
          * @brief Returns whether the current user can add children to folders
@@ -273,14 +274,14 @@ class KGAPIDRIVE_EXPORT Drives: public KGAPI2::Object
          */
         bool canTrashChildren() const;
 
-      private:
+    private:
         class Private;
         QScopedPointer<Private> const d;
         friend class Private;
         friend class Drives;
     };
 
-    typedef QSharedPointer<Capabilities> CapabilitiesPtr;
+    using CapabilitiesPtr = QSharedPointer<Capabilities>;
 
     /**
      * @brief Drives::BackgroundImageFile holds the structure used
@@ -288,8 +289,7 @@ class KGAPIDRIVE_EXPORT Drives: public KGAPI2::Object
      */
     class BackgroundImageFile
     {
-
-      public:
+    public:
         struct Fields {
             static const QString Id;
             static const QString XCoordinate;
@@ -301,7 +301,10 @@ class KGAPIDRIVE_EXPORT Drives: public KGAPI2::Object
         BackgroundImageFile(const BackgroundImageFile &other);
         ~BackgroundImageFile();
         bool operator==(const BackgroundImageFile &other) const;
-        bool operator!=(const BackgroundImageFile &other) const { return !operator==(other); }
+        bool operator!=(const BackgroundImageFile &other) const
+        {
+            return !operator==(other);
+        }
 
         /**
          * @brief Returns the ID of an image file in Google Drive
@@ -381,14 +384,14 @@ class KGAPIDRIVE_EXPORT Drives: public KGAPI2::Object
          */
         void setWidth(float width) const;
 
-      private:
+    private:
         class Private;
         QScopedPointer<Private> const d;
         friend class Private;
         friend class Drives;
     };
 
-    typedef QSharedPointer<BackgroundImageFile> BackgroundImageFilePtr;
+    using BackgroundImageFilePtr = QSharedPointer<BackgroundImageFile>;
 
     struct Fields {
         static const QString Kind;
@@ -412,7 +415,10 @@ class KGAPIDRIVE_EXPORT Drives: public KGAPI2::Object
     Drives(const Drives &other);
     ~Drives() override;
     bool operator==(const Drives &other) const;
-    bool operator!=(const Drives &other) const { return !operator==(other); }
+    bool operator!=(const Drives &other) const
+    {
+        return !operator==(other);
+    }
 
     /**
      * @brief Returns the ID of this shared drive which
@@ -515,7 +521,7 @@ class KGAPIDRIVE_EXPORT Drives: public KGAPI2::Object
     static DrivesList fromJSONFeed(const QByteArray &jsonData, FeedData &feedData);
     static QByteArray toJSON(const DrivesPtr &drives);
 
-  private:
+private:
     class Private;
     QScopedPointer<Private> const d;
     friend class Private;
@@ -524,5 +530,3 @@ class KGAPIDRIVE_EXPORT Drives: public KGAPI2::Object
 } /* namespace Drive */
 
 } /* namespace KGAPI2 */
-
-#endif // LIBKGAPI2_DRIVEDRIVES_H
